pub type StdHashSuite = Sha256HashSuite;Expand description
The standard hash suite pairs the standard digest with the standard compression.
Aliased Type
pub struct StdHashSuite;pub type StdHashSuite = Sha256HashSuite;The standard hash suite pairs the standard digest with the standard compression.
pub struct StdHashSuite;